<?php
 /**
  * 
  * @package    BizReview - Business and google Place Review WordPress Plugin
  * @version    1.0
  * @author     ThemeAtelier
  * @Websites: https://themeatelier.net/
  *
  */
 
 class Bizreview_Settings_Page
{

    /**
     * Start up
     */
    public function __construct()
    {

        $bizrev_options = get_option( 'bizreview_options' );
		
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );

        if( !empty( $bizrev_options['countswitch'] ) ) {
            add_action( 'wp_dashboard_setup', array( $this, 'visitor_statistics_widget' ) );
        }

       
    }

    /**
     * Add options page
     */
    public function add_plugin_page()
    {
        // This page will be under "Settings"
		add_menu_page(
			esc_html__( 'Biz Review', 'bizreview' ),
			esc_html__( 'Biz Review Settings', 'bizreview' ),
			'manage_options',
			'bizreview-setting-admin',
			array( $this, 'create_admin_page' ),
			'dashicons-universal-access',
			6
		);
	    add_submenu_page(
            'bizreview-setting-admin',
            esc_html__( 'Custom Review', 'bizreview' ),
            esc_html__( 'Custom Review', 'bizreview' ),
            'manage_options',
            'edit.php?post_type=bizreview',
            NULL
        );
        add_submenu_page(
            'bizreview-setting-admin',
            esc_html__( 'Custom Review Categories', 'bizreview' ),
            esc_html__( 'Custom Review Categories', 'bizreview' ),
            'manage_options',
            'edit-tags.php?taxonomy=review_category&post_type=bizreview',
            NULL
        );
        add_submenu_page(
            'bizreview-setting-admin',
            esc_html__( 'Review Badges', 'bizreview' ),
            esc_html__( 'Review Badges', 'bizreview' ),
            'manage_options',
            'edit.php?post_type=reviewbadges',
            NULL
        );
    }

	
	/**
	 * Custom review categories
	 */
	 
	public function custom_review_categories(){
                
        $terms = get_terms( 'review_category', array(
            'hide_empty' => true,
        ) );

        return $terms;
        
	}
	
    function page_init() {
        //register our settings
        register_setting( 'my-cool-plugin-settings-group', 'bizreview_options' );
    }


    /**
     * Options page callback
     */
    public function create_admin_page()
    {
        
        ?>
        <div class="bizreview-admin-wrap">

            <ul class="settings-menu">
				<li><a href="#admin_general" class="bizreview-tab"><?php esc_html_e( 'General', 'bizreview' ); ?></a></li>
				<li><a href="#admin_greview" class="bizreview-tab"><?php esc_html_e( 'Google Review', 'bizreview' ); ?></a></li>
				<li><a href="#admin_fbreview" class="bizreview-tab"><?php esc_html_e( 'Facebook Review', 'bizreview' ); ?></a></li>
                <li><a href="#admin_yelp" class="bizreview-tab"><?php esc_html_e( 'Yelp Review', 'bizreview' ); ?></a></li>
			</ul>   

			<?php 
			// add error/update messages
	        
			// check if the user have submitted the settings
			if ( isset( $_GET['settings-updated'] ) ) {
			// add settings saved message with the class of "updated"
			add_settings_error( 'bizreview_messages', 'bizreview_message', __( 'Settings Saved', 'bizreview' ), 'updated' );
			}
			
			// show error/update messages
			settings_errors( 'bizreview_messages' );


            $argsData = array(

            );

           // update_option( 'bizreview_options', $argsData );

            $bizrev_options = get_option( 'bizreview_options' );

			?>
            <form class="admin-bizreview" method="post" action="options.php">
			    <?php settings_fields( 'my-cool-plugin-settings-group' ); ?>
                <?php do_settings_sections( 'my-cool-plugin-settings-group' ); ?>

                <div id="admin_general" class="bizreview-admin-general bizr-active">

                    <div class="bizreview-label bizreview-field-wrp">
                        <?php 
                        $trimcharacter = !empty( $bizrev_options['trimcharacter'] ) ? $bizrev_options['trimcharacter'] : '100';
                        ?>
                        <h5><?php esc_html_e( 'Long Review Trim Characters', 'bizreview' ); ?></h5>
                        <input type="number" class="input-control" name="bizreview_options[trimcharacter]" value="<?php echo esc_html( $trimcharacter ); ?>"/>
                    </div>
                    <div class="bizreview-label bizreview-field-wrp">
                        <?php 
                        $countswitch = !empty( $bizrev_options['countswitch'] ) ? $bizrev_options['countswitch'] : '';
                        ?>
                        <h5><?php esc_html_e( 'Use Visitor Statistic', 'bizreview' ); ?></h5>
                        <input type="checkbox" class="mt-8 input-control" name="bizreview_options[countswitch]" value="1" <?php checked( $countswitch , 1) ?> />
                    </div>
                    <div class="bizreview-label bizreview-field-wrp">
                        <?php 
                        $dateformat = !empty( $bizrev_options['dateformat'] ) ? $bizrev_options['dateformat'] : 'F j, Y';
                        
                        ?>
                        <h5><?php esc_html_e( 'Review Date Format', 'bizreview' ); ?></h5>
                        <select id="dateformat" name="bizreview_options[dateformat]">
                            <option  value="none"><?php esc_html_e( 'Select Date Format', 'bizreview' ); ?></option>
                            <option <?php selected( $dateformat, 'F j, Y' ) ?> value="F j, Y"><?php esc_html_e( 'September 7, 2019', 'bizreview' ); ?></option>
							<option <?php selected( $dateformat, 'F Y' ) ?> value="F Y"><?php esc_html_e( 'September 2019', 'bizreview' ); ?></option>
                            <option <?php selected( $dateformat, 'Y-m-d' ) ?> value="Y-m-d"><?php esc_html_e( '2019-09-07', 'bizreview' ); ?></option>
                            <option <?php selected( $dateformat, 'm/d/Y' ) ?> value="m/d/Y"><?php esc_html_e( '09/07/2019', 'bizreview' ); ?></option>
                            <option <?php selected( $dateformat, 'd/m/Y' ) ?> value="d/m/Y"><?php esc_html_e( '07/09/2019', 'bizreview' ); ?></option>
                        </select>
                    </div>


                    <div class="shortcode-generator">
                        <h2><?php esc_html_e( 'Review Shortcode Generator', 'bizreview' ); ?></h2>
                        <div class="scode-generator">
                            <select id="reviewtype">
                                <option value=""><?php esc_html_e( 'Select Review Type', 'bizreview' ); ?></option>
                                <option value="bizr_google_place"><?php esc_html_e( 'Google Review', 'bizreview' ); ?></option>
                                <option value="bizr_custom_reviews"><?php esc_html_e( 'Custom Review', 'bizreview' ); ?></option>
                                <option value="bizr_facebook_review"><?php esc_html_e( 'Facebook Review', 'bizreview' ); ?></option>
                                <option value="bizr_yelp_review"><?php esc_html_e( 'Yelp Review', 'bizreview' ); ?></option>
                            </select>
                            <select id="reviewcat">
                                <option value=""><?php esc_html_e( 'Select Custom Review Category', 'bizreview' ); ?></option>
                                <?php 
                                $categories = $this->custom_review_categories();
                                if( !empty( $categories ) ) {
                                    foreach( $categories as $category) {
                                        echo '<option value="'.esc_attr( $category->slug ).'">'.esc_html( $category->name ).'</option>';
                                    }
                                }
                                ?>
                            </select>
                            <select id="order">
                                <option value=""><?php esc_html_e( 'Rating Order', 'bizreview' ); ?></option>
                                <option value="DESC"><?php esc_html_e( 'DESC', 'bizreview' ); ?></option>
                                <option value="ASC"><?php esc_html_e( 'ASC', 'bizreview' ); ?></option>
                            </select>
                            <select id="gplaceinfo">
                                <option value=""><?php esc_html_e( 'Place Info', 'bizreview' ); ?></option>
                                <option value="show"><?php esc_html_e( 'Show', 'bizreview' ); ?></option>
                                <option value="hide"><?php esc_html_e( 'Hide', 'bizreview' ); ?></option>
                            </select>
                            <input type="number" id="max_rows" placeholder="<?php esc_html_e( 'Max Reviews', 'bizreview' ); ?>" value="5" name="max_rows" />
                            <input type="number" id="min_rating" placeholder="<?php esc_html_e( 'Min Rating', 'bizreview' ); ?>" value="1" name="min_rating" />
                            <input type="number" id="padding_top" placeholder="<?php esc_html_e( 'Padding Top', 'bizreview' ); ?>" value="50" name="padding_top" />
                            <input type="number" id="padding_bottom" placeholder="<?php esc_html_e( 'Padding Bottom', 'bizreview' ); ?>" value="50" name="padding_bottom" />
                            <input type="text" id="bg_color" placeholder="<?php esc_html_e( 'Background Color', 'bizreview' ); ?>" value="#fff" name="bg_color" />
                            <select id="bizstyle">
                                <option value="1"><?php esc_html_e( 'Select Template Style', 'bizreview' ); ?></option>
                                <option value="1"><?php esc_html_e( 'Style 1 (Grid)', 'bizreview' ); ?></option>
                                <option value="2"><?php esc_html_e( 'Style 2 (Grid)', 'bizreview' ); ?></option>
                                <option value="3"><?php esc_html_e( 'Style 3 (Grid)', 'bizreview' ); ?></option>
                                <option value="4"><?php esc_html_e( 'Style 4 (Grid)', 'bizreview' ); ?></option>
                                <option value="5"><?php esc_html_e( 'Style 5 (Grid)', 'bizreview' ); ?></option>
                                <option value="6"><?php esc_html_e( 'Style 6 (Grid)', 'bizreview' ); ?></option>
                                <option value="7"><?php esc_html_e( 'Style 7 (Grid)', 'bizreview' ); ?></option>
                                <option value="8"><?php esc_html_e( 'Style 8 (Masonary)', 'bizreview' ); ?></option>
                                <option value="9"><?php esc_html_e( 'Style 9 (Slider)', 'bizreview' ); ?></option>
                                <option value="10"><?php esc_html_e( 'Style 10 (Slider)', 'bizreview' ); ?></option>
                                <option value="11"><?php esc_html_e( 'Style 11 (Slider)', 'bizreview' ); ?></option>
                                <option value="12"><?php esc_html_e( 'Style 12 (Slider)', 'bizreview' ); ?></option>
                                <option value="13"><?php esc_html_e( 'Style 13 (Slider)', 'bizreview' ); ?></option>
                                <option value="14"><?php esc_html_e( 'Style 14 (Slider)', 'bizreview' ); ?></option>
                            </select>
                            <div class="button-area">
                                <span id="scodegenerate"><?php esc_html_e( 'Generate', 'bizreview' ); ?></span>
                                <span id="scode-copy"><?php esc_html_e( 'Copy', 'bizreview' ); ?></span>
                            </div>
                        </div>
                        <div class="scode-show"></div>
                    </div>

                    <!-- Badges Shortcode -->
                    <div class="clear-fix"></div>
                    <div class="shortcode-generator">
                        <h2><?php esc_html_e( 'Review Badges Shortcode Generator', 'bizreview' ); ?></h2>
                        <div class="scode-generator">
                            <div class="field-group ">
                                <select id="badgestype">
                                    <option value=""><?php esc_html_e( 'Select Review Badges Type', 'bizreview' ); ?></option>
                                    <option value="biz_badges"><?php esc_html_e( 'Review Badge', 'bizreview' ); ?></option>
                                    <option value="biz_badges_slider"><?php esc_html_e( 'Review Slider Badges', 'bizreview' ); ?></option>
                                </select>
                            </div>
                            <div class="field-group field-group-margin">
                                <label><?php esc_html_e( 'Select Review Badges', 'bizreview' ); ?></label>
                                <select id="badgelist" name="badge_id">
                                    <option><?php esc_html_e( 'Select Review Badges', 'bizreview' ); ?></option>
                                    <?php 
                                    $badges = bizreview_get_badges();
                                    if( !empty( $badges ) ) {
                                        foreach( $badges as $val ) {
                                            echo '<option value="'.$val->ID.'">'.$val->post_title.'</option>';
                                        }
                                    }
                                    ?>
                                </select>
                            </div>
                            <div class="field-group field-group-margin">
                            <label><?php esc_html_e( 'Margin Top', 'bizreview' ); ?></label>
                            <input type="number" id="margin_top" placeholder="<?php esc_html_e( 'Margin Top', 'bizreview' ); ?>" value="0" name="margin_top" />
                            </div>
                            <div class="field-group field-group-margin">
                            <label><?php esc_html_e( 'Margin Bottom', 'bizreview' ); ?></label>
                            <input type="number" id="margin_bottom" placeholder="<?php esc_html_e( 'Margin Bottom', 'bizreview' ); ?>" value="0" name="margin_bottom" />
                            </div>
                            
                            <div class="field-group">
                            <label><?php esc_html_e( 'Padding Top', 'bizreview' ); ?></label>
                            <input type="number" id="badge_padding_top" placeholder="<?php esc_html_e( 'Padding Top', 'bizreview' ); ?>" value="50" name="padding_top" />
                            </div>
                            <div class="field-group">
                                <label><?php esc_html_e( 'Padding Bottom', 'bizreview' ); ?></label>
                                <input type="number" id="badge_padding_bottom" placeholder="<?php esc_html_e( 'Padding Bottom', 'bizreview' ); ?>" value="50" name="padding_bottom" />
                            </div>
                            <div class="field-group">
                                <label><?php esc_html_e( 'Background Color', 'bizreview' ); ?></label>
                                <input type="text" id="badge_bg_color" placeholder="<?php esc_html_e( 'Background Color', 'bizreview' ); ?>" value="#fff" name="bg_color" />
                            </div>
                            <div class="button-badges-area">
                                <span id="badges_scode_generate"><?php esc_html_e( 'Generate', 'bizreview' ); ?></span>
                                <span id="scode-badges-copy"><?php esc_html_e( 'Copy', 'bizreview' ); ?></span>
                            </div>
                        </div>
                        <div class="scode-badges-show"></div>
                    </div>
                </div>
                <!-- Google Review -->
                <div id="admin_greview" class="bizreview-admin-greview bizr-hide">
                    <?php
                    $gookey = !empty( $bizrev_options['gookey'] ) ? $bizrev_options['gookey'] : '';
                    $gplaceid = !empty( $bizrev_options['gplaceid'] ) ? $bizrev_options['gplaceid'] : '';
                    ?>
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Set Google Api Key', 'bizreview' ); ?></h5>
                        <input type="text" class="mt-8 input-control" name="bizreview_options[gookey]" value="<?php echo esc_html( $gookey ); ?>"/>
                    </div> 
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Set Global Google Place ID', 'bizreview' ); ?></h5>
                        <input type="text" class="mt-8 input-control" name="bizreview_options[gplaceid]" value="<?php echo esc_html( $gplaceid ); ?>"/>
                        <p>
                        <a href="https://developers.google.com/places/place-id" target="_blank"><?php esc_html_e( 'Find google Place ID', 'bizreview' ); ?></a>
                        </p>
                    </div> 
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Click the button to upload google reviews in your database.', 'bizreview' ); ?></h5>
                        <span class="status-message"></span>
                        <span class="get-google-review"><?php esc_html_e( 'Get Google Reviews', 'bizreview' ); ?></span>
                        
                    </div> 
                </div>
                <!-- Facebook Review -->
                <div id="admin_fbreview" class="bizreview-admin-fbreview bizr-hide">
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Login with facebook to get access token', 'bizreview' ); ?></h5>
                        <div class="fb-loginbtn mt-8"><span class="bizfb-connect"><?php esc_html_e( 'Login With Facebook', 'bizreview' ); ?></span></div>
                    </div>
                    <div class="fbrev-pages"></div>
                    <?php
                    $fbkey = !empty( $bizrev_options['fbkey'] ) ? $bizrev_options['fbkey'] : '';
                    $pagename = !empty( $bizrev_options['pagename'] ) ? $bizrev_options['pagename'] : '';
                    $pageid = !empty( $bizrev_options['pageid'] ) ? $bizrev_options['pageid'] : '';
                    ?>
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Access Token', 'bizreview' ); ?></h5>
                        <input type="text" class="mt-8 fbkey input-control" name="bizreview_options[fbkey]" value="<?php echo esc_html( $fbkey ); ?>"  readonly/>
                    </div>
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Page Name', 'bizreview' ); ?></h5>
                        <input type="text" class="mt-8 pagename input-control" name="bizreview_options[pagename]" value="<?php echo esc_html( $pagename ); ?>" readonly />
                    </div>
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Page ID', 'bizreview' ); ?></h5>
                        <input type="text" class="mt-8 pageid input-control" name="bizreview_options[pageid]" value="<?php echo esc_html( $pageid ); ?>" readonly />
                    </div>
                    
                </div>
                <!-- Yelp Review -->
                <div id="admin_yelp" class="bizreview-admin-fbreview bizr-hide">
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Yelp Settings', 'bizreview' ); ?></h5>
                    </div>



                    <?php
                    $yelpApiKey = !empty( $bizrev_options['yelpapikey'] ) ? $bizrev_options['yelpapikey'] : '';
                    $busid = !empty( $bizrev_options['busid'] ) ? $bizrev_options['busid'] : '';
                    ?>
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Api key', 'bizreview' ); ?></h5>
                        <input type="text" class="mt-8 input-control" name="bizreview_options[yelpapikey]" value="<?php echo esc_html( $yelpApiKey ); ?>" />
                    </div>
                    <div class="notice notice-success is-dismissible p-5">
        
                            Create an app by following this link <a href="https://www.yelp.com/developers/v3/manage_app">https://www.yelp.com/developers/v3/manage_app</a> and get the API key from there.
                    </div>
                    <div class="bizreview-label bizreview-field-wrp">
                        <h5><?php esc_html_e( 'Businesses ID', 'bizreview' ); ?></h5>
                        <input type="text" class="mt-8 input-control" name="bizreview_options[busid]" value="<?php echo esc_html( $busid ); ?>" />
                    </div>
                    <div class="wrap notice notice-success is-dismissible">

<ul>
<li>You will find the Business ID on the Yelp’s Business URL</li>
<li>Observe that it will appear after www.yelp.com/biz/ in the address bar and it contains the name and location of the business separated by dashes.</li>
<li>For example, the Business ID in the following URL is “rh-rooftop-restaurant-new-york-3“: <a href="https://www.yelp.com/biz/rh-rooftop-restaurant-new-york-3">https://www.yelp.com/biz/rh-rooftop-restaurant-new-york-3</a></li>
</ul>
                                </div>


                </div>

            <?php
            // Save Button                    
            submit_button(); 
            ?>
            </form>
        </div>
        <?php
    }

    // Dashboard widget
    
    function visitor_statistics_widget() {

        wp_add_dashboard_widget(
                'visitor-statistics',     // Widget slug.
                'Visitor Statistics',    // Title.
                array( $this, 'visitor_statistics_widget_callback' ) // Display function.
        );  

    }
	
    function visitor_statistics_widget_callback() {
        
        $day    = date('z');
        $week   = date('W');
        $month  = date('n');
        $year   = date( 'Y' );


        $day_statistics_id    = $day.'_'.$year;
        $week_statistics_id   = $week.'_'.$month.'_'.$year;
        $month_statistics_id  = $month.'_'.$year;
        $year_statistics_id   = $year;



        $day_get_row = biz_get_table_row( 'biz_visitor_statistics', 'statistics_id', $day_statistics_id );
        $week_get_row = biz_get_table_row( 'biz_visitor_statistics', 'statistics_id', $week_statistics_id );
        $month_get_row = biz_get_table_row( 'biz_visitor_statistics', 'statistics_id', $month_statistics_id );
        $year_get_row = biz_get_table_row( 'biz_visitor_statistics', 'statistics_id', $year_statistics_id );


        ?>
        <div style="width:200px;margin: 0 auto">
           <div style="border:1px solid #000000;padding:8px;width:100%;font-size:15px;font-weight:bold;">
              <img src="<?php echo BIZREVIEW_DIR_URL.'assets/' ?>counter.gif" width="16" height="16" border="0" /> Visitor Statistics 
           </div>

           <div style="border:1px solid #000000;padding:8px;width:100%;font-size:15px;"> 
              &raquo; <?php echo $day_get_row[4]; _e( ' Today', 'bizreview'); ?> <br /><br />
              &raquo; <?php echo $week_get_row[4]; _e( ' This Week', 'bizreview' ); ?> <br /><br />
              &raquo; <?php echo $month_get_row[4]; _e( ' This Month', 'bizreview' ) ;?> <br /><br />
              &raquo; <?php echo $year_get_row[4]; _e( ' This Year', 'bizreview' ); ?> <br />
           </div>
        </div>

        <?php 
    }
	
}

if( is_admin() )
    $bizreview_settings_page = new Bizreview_Settings_Page();

  