<?php
namespace Bizreviewelementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;



// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * Laamya elementor about page section widget.
 *
 * @since 1.0
 */
class Bizreview_Social_Badges extends Widget_Base {

	public function get_name() {
		return 'bizreview-social-badges';
	}

	public function get_title() {
		return __( 'Review Badges', 'bizreview' );
	}

	public function get_icon() {
		return 'eicon-rating';
	}

	public function get_categories() {
		return [ 'bizreview-elements' ];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();


        // ----------------------------------------  Custom Review Settings ------------------------------
        $this->start_controls_section(
            'bizreview_badges_set',
            [
                'label' => esc_html__( 'Social Badges Settings', 'bizreview' ),
            ]
        );

        $this->add_control(
            'badges_platform', [
                'label' => esc_html__( 'Badges Platform', 'bizreview' ),
                'type'  => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => array(
                    'google' => esc_html__( 'Google', 'bizreview' ),
                    'facebook' => esc_html__( 'Facebook', 'bizreview' ),
                    'yelp' => esc_html__( 'Yelp', 'bizreview' ),
                    'trustpilot' => esc_html__( 'Trustpilot', 'bizreview' ),
                )

            ]
        );
        $this->add_control(
            'name', [
                'label' => esc_html__( 'Platform Name', 'bizreview' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => true,

            ]
        );
        
        $this->add_control(
            'img', [
                'label' => esc_html__( 'Platform Image', 'bizreview' ),
                'type'  => Controls_Manager::MEDIA,
                'label_block' => true,

            ]
        );
        $this->add_control(
            'rating', [
                'label' => esc_html__( 'Rating', 'bizreview' ),
                'type'  => Controls_Manager::NUMBER,
                'label_block' => true,

            ]
        );
        $this->add_control(
            'totalreview', [
                'label' => esc_html__( 'Total Reviews', 'bizreview' ),
                'type'  => Controls_Manager::NUMBER,
                'label_block' => true,

            ]
        );
        $this->add_control(
            'reviewurl', [
                'label' => esc_html__( 'Reviews Url', 'bizreview' ),
                'type'  => Controls_Manager::TEXT,
                'label_block' => true,

            ]
        );

        $this->end_controls_section(); // End section top content

	}

	protected function render() {

    $settings = $this->get_settings();

    ?>
    <div class="badges-wrapper">
        <div class="badges-inner">
            <div class="title-img">
                <?php
                    //
                    if( ! empty( $settings['img']['url'] ) ) {
                        echo '<img class="badges-img" src="'.esc_url( $settings['img']['url'] ).'" alt="'.esc_attr( $settings['name'] ).'" />';
                    }
                    // Title
                    if( ! empty( $settings['name'] ) ) {
                        echo '<h3>'.esc_html( $settings['name'] ).'</h3>';
                    }
                ?>
            </div>
            <div class="rating <?php echo esc_attr( $settings['badges_platform'] ) ?>">
                <?php 
                //
                if( ! empty( $settings['rating'] ) ) {
                    $ratings = $settings['rating'];
                    echo '<span>'.esc_html( $ratings ).'</span>';
                    echo '<span>'.bizreview_star_review( esc_html( $ratings ) ).'</span>';
                }
                //

                ?>
            </div>
            <div class="badges-footer">
                <?php
                //
                if( ! empty( $settings['totalreview'] ) ) {
                    echo '<span>'.sprintf( esc_html__( 'Based on %s reviews', 'bizreview' ), esc_html( $settings['totalreview'] ) ).'</span>';
                } 
                //
                if( ! empty( $settings['reviewurl'] ) ) {
                    echo '<span><a href="'.esc_url( $settings['reviewurl'] ).'" target="_blank">'.esc_html__( 'View Reviews', 'bizreview' ).'</a></span>';
                }
                ?>
            </div>
        </div>
    </div>
    <?php
    }
	
}
