<?php 
 /**
  * 
  * @package    BizReview - Business and google Place Review WordPress Plugin
  * @version    1.0
  * @author     ThemeAtelier
  * @Websites: https://themeatelier.net/
  *
  */
  
// Blocking direct access
if( ! defined( 'ABSPATH' ) ) {
    die ( BIZREVIEW_ALERT_MSG );
}

/**************************************
*Creating Widget
***************************************/
 
class bizreview_badges_widget extends WP_Widget {


function __construct() {

parent::__construct(
// Base ID of your widget
'bizreview_badges_widget', 


// Widget name will appear in UI
esc_html__( 'Review Badges [BizReview]', 'bizreview' ),

// Widget description
array( 'description' => esc_html__( 'Add review badges widget.', 'bizreview' ), ) 
);

}

// This is where the action happens
public function widget( $args, $instance ) {
$title 				= apply_filters( 'widget_title', $instance['title'] );
$selectedBadges 	= apply_filters( 'widget_badges', $instance['badges'] );

// before and after widget arguments are defined by themes
echo wp_kses_post( $args['before_widget'] );
if ( ! empty( $title ) )
echo wp_kses_post( $args['before_title'] . $title . $args['after_title'] );

// Get Reviews Badges

$postArgs = array(
	'post_type' => 'reviewbadges',
	'posts_per_page' => '-1',
	'post__in' => $selectedBadges
);

$badges = new WP_Query( $postArgs );

if( $badges->have_posts() ):
	echo '<div class="widgets-badges-wrapper">';
	while( $badges->have_posts() ):
		$badges->the_post();

		$postID = get_the_ID();

		$platform        = get_post_meta( $postID, 'bizreviewbadges_platform', true );
		$name       	 = get_post_meta( $postID, 'bizreviewplarform_name', true );
		$pic       		 = get_post_meta( $postID, 'bizreviewplatform_pic', true );
		$ratings      	 = get_post_meta( $postID, 'bizreviewratings', true );
		$totalReview     = get_post_meta( $postID, 'bizreviewtotal_reviews', true );
		$reviewUrl       = get_post_meta( $postID, 'bizreviewreviews_url', true );

		$img = wp_get_attachment_image_src( $pic, 'full' );
?>

	<div class="widgets-badges-inner">
		<div class="title-img">
			<?php
				//
				if( ! empty( $img[0] ) ) {
					echo '<img class="badges-img" src="'.esc_url( $img[0] ).'" alt="'.esc_attr( $name ).'" />';
				}
				// Title
				if( ! empty( $name ) ) {
					echo '<h4>'.esc_html( $name ).'</h4>';
				}
			?>
		</div>
		<div class="rating <?php echo esc_html( $platform ); ?>">
			<?php 
			//
			if( ! empty( $ratings ) ) {
				echo '<span>'.esc_html( $ratings ).'</span>';
				echo '<span>'.bizreview_star_review( esc_html( $ratings ) ).'</span>';
			}
			//

			?>
		</div>
		<div class="badges-footer">
			<?php
			//
			if( ! empty( $totalReview ) ) {
				echo '<span>'.sprintf( esc_html__( 'Based on %s reviews', 'bizreview' ), esc_html( $totalReview ) ).'</span>';
			} 
			//
			if( ! empty( $reviewUrl ) ) {
				echo '<span><a href="'.esc_url( $reviewUrl ).'" target="_blank">'.esc_html__( 'View Review', 'bizreview' ).'</a></span>';
			}
			?>
		</div>
	</div>

<?php
endwhile;
echo '</div>';
endif;

echo wp_kses_post( $args['after_widget'] );
}
		
// Widget Backend 
public function form( $instance ) {
	
if ( isset( $instance[ 'title' ] ) ) {
	$title = $instance[ 'title' ];
}else {
	$title = esc_html__( 'Review Badges', 'bizreview' );
}
	
if ( isset( $instance[ 'badges' ] ) ) {
	$badges = $instance[ 'badges' ];
}else {
	$badges = '';
}

// Widget admin form
?>
<p>
<label style="font-weight:bold;margin-bottom:10px;display: block;" for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:' ,'bizreview'); ?></label> 
<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
</p>
<?php
$postArgs = array(
	'post_type' => 'reviewbadges',
	'posts_per_page' => '-1' 
);

$badgesPosts = get_posts( $postArgs );

if( $badgesPosts ) {
	echo '<div class="badges-checkbox"><div style="font-weight:bold;margin-bottom:10px">'.esc_html__( 'Select Badges', 'bizreview' ).'</div>';
	foreach( $badgesPosts as $value  ) {
		$checked = '';
		if( ! empty( $badges ) && in_array( $value->ID, $badges ) ) {
			$checked = 'checked';
		}
		?>
		<label><?php echo esc_html( $value->post_title ) ?>
		<input type="checkbox" name="<?php echo $this->get_field_name( 'badges' ).'[]'; ?>" <?php echo esc_attr( $checked ); ?> value="<?php echo esc_attr( $value->ID ) ?>" />
		</label>
		<?php
	}
	echo '</div>';
}

}
	
// Updating widget replacing old instances with new
public function update( $new_instance, $old_instance ) {

$instance = array();
$instance['title'] 	  	= ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
$instance['badges']  	= ( ! empty( $new_instance['badges'] ) ) ?  $new_instance['badges']  : '';

return $instance;
}

} // Class  ends here


// Register and load the widget
function bizreview_badges_init_widget() {
	register_widget( 'bizreview_badges_widget' );
}
add_action( 'widgets_init', 'bizreview_badges_init_widget' );
	
